==> sfml-2.6.0-3-aarch64.pkg.tar.xz: usr/share/doc/SFML/html/search/enumvalues_e.js <==
var searchData=
[
  ['o_0',['O',['../structsf_1_1Keyboard_1_1Scan.html#aa42fbf6954d6f81f7606e566c7abe875aafe949e3a5c03b8981026f5b9621154b',1,'sf::Keyboard::Scan::O'],['../classsf_1_1Keyboard.html#acb4cacd7cc5802dec45724cf3314a142a7739288cc628dfa8c50ba712be7c03e1',1,'sf::Keyboard::O']]],
  ['ok_1',['Ok',['../classsf_1_1Ftp_1_1Response.html#af81738f06b6f571761696291276acb3baa956e229ba6c0cdf0d88b0e05b286210',1,'sf::Ftp::Response::Ok'],['../classsf_1_1Http_1_1Response.html#a663e071978e30fbbeb20ed045be874d8a0158f932254d3f09647dd1f64bd43832',1,'sf::Http::Response::Ok']]],
  ['one_2',['One',['../structsf_1_1BlendMode.html#afb9852caf356b53bb0de460c58a9ebbbaa2d3ba8b8bb2233c9d357cbb94bf4181',1,'sf::BlendMode']]],
  ['oneminusdstalpha_3',['OneMinusDstAlpha',['../structsf_1_1BlendMode.html#afb9852caf356b53bb0de460c58a9ebbbab4e5c63f189f26075e5939ad1a2ce4e4',1,'sf::BlendMode']]],
  ['oneminusdstcolor_4',['OneMinusDstColor',['../structsf_1_1BlendMode.html#afb9852caf356b53bb0de460c58a9ebbbac8198db20d14506a841d1091ced1cae2',1,'sf::BlendMode']]],
  ['oneminussrcalpha_5',['OneMinusSrcAlpha',['../structsf_1_1BlendMode.html#afb9852caf356b53bb0de460c58a9ebbbaab57e8616bf4c21d8ee923178acdf2c8',1,'sf::BlendMode']]],
  ['oneminussrccolor_6',['OneMinusSrcColor',['../structsf_1_1BlendMode.html#afb9852caf356b53bb0de460c58a9ebbba5971ffdbca63382058ccba76bfce219e',1,'sf::BlendMode']]],
  ['openingdataconnection_7',['OpeningDataConnection',['../classsf_1_1Ftp_1_1Response.html#af81738f06b6f571761696291276acb3ba794ebe743688be611447638bf9e49d86',1,'sf::Ftp::Response']]],
  ['orientation_8',['Orientation',['../classsf_1_1Sensor.html#a687375af3ab77b818fca73735bcaea84aa428c5260446555de87c69b65f6edf00',1,'sf::Sensor']]]
];

==> sfml-2.6.1-1-aarch64.pkg.tar.xz: usr/share/doc/SFML/html/search/enumvalues_e.js <==
var searchData=
[
  ['o_0',['o',['../structsf_1_1Keyboard_1_1Scan.html#aa42fbf6954d6f81f7606e566c7abe875aafe949e3a5c03b8981026f5b9621154b',1,'sf::Keyboard::Scan::O'],['../classsf_1_1Keyboard.html#acb4cacd7cc5802dec45724cf3314a142a7739288cc628dfa8c50ba712be7c03e1',1,'sf::Keyboard::O']]],
  ['ok_1',['ok',['../classsf_1_1Ftp_1_1Response.html#af81738f06b6f571761696291276acb3baa956e229ba6c0cdf0d88b0e05b286210',1,'sf::Ftp::Response::Ok'],['../classsf_1_1Http_1_1Response.html#a663e071978e30fbbeb20ed045be874d8a0158f932254d3f09647dd1f64bd43832',1,'sf::Http::Response::Ok']]],
  ['one_2',['One',['../structsf_1_1BlendMode.html#afb9852caf356b53bb0de460c58a9ebbbaa2d3ba8b8bb2233c9d357cbb94bf4181',1,'sf::BlendMode']]],
  ['oneminusdstalpha_3',['OneMinusDstAlpha',['../structsf_1_1BlendMode.html#afb9852caf356b53bb0de460c58a9ebbbab4e5c63f189f26075e5939ad1a2ce4e4',1,'sf::BlendMode']]],
  ['oneminusdstcolor_4',['OneMinusDstColor',['../structsf_1_1BlendMode.html#afb9852caf356b53bb0de460c58a9ebbbac8198db20d14506a841d1091ced1cae2',1,'sf::BlendMode']]],
  ['oneminussrcalpha_5',['OneMinusSrcAlpha',['../structsf_1_1BlendMode.html#afb9852caf356b53bb0de460c58a9ebbbaab57e8616bf4c21d8ee923178acdf2c8',1,'sf::BlendMode']]],
  ['oneminussrccolor_6',['OneMinusSrcColor',['../structsf_1_1BlendMode.html#afb9852caf356b53bb0de460c58a9ebbba5971ffdbca63382058ccba76bfce219e',1,'sf::BlendMode']]],
  ['openingdataconnection_7',['OpeningDataConnection',['../classsf_1_1Ftp_1_1Response.html#af81738f06b6f571761696291276acb3ba794ebe743688be611447638bf9e49d86',1,'sf::Ftp::Response']]],
  ['orientation_8',['Orientation',['../classsf_1_1Sensor.html#a687375af3ab77b818fca73735bcaea84aa428c5260446555de87c69b65f6edf00',1,'sf::Sensor']]]
];
